Actions, Resources, and Condition Keys for AWS SSO Directory - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for AWS SSO Directory

AWS SSO Directory (service prefix: `sso-directory` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS SSO Directory
- Resource Types Defined by AWS SSO Directory
- Condition Keys for AWS SSO Directory

## Actions Defined by AWS SSO Directory

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AddMemberToGroup | Adds member to the group in the directory that AWS SSO provides by default | Write |  |  |
CompleteVirtualMfaDeviceRegistration | Completes the creation process of a virtual MFA device | Write |  |  |
CreateAlias | Creates an alias for the directory that AWS SSO provides by default | Write |  |  |
CreateBearerToken | Creates a bearer token for a given provisioning tenant. | Write |  |  |
CreateExternalIdPConfigurationForDirectory | Create an External Identity Provider configuration for the directory | Write |  |  |
CreateGroup | Creates a group in the directory that AWS SSO provides by default | Write |  |  |
CreateProvisioningTenant | Creates a provisioning tenant for a given directory. | Write |  |  |
CreateUser | Creates a user in the directory that AWS SSO provides by default | Write |  |  |
DeleteBearerToken | Deletes the bearer token. | Write |  |  |
DeleteExternalIdPConfigurationForDirectory | Delete an External Identity Provider configuration associated with the directory | Write |  |  |
DeleteGroup | Deletes a group from the directory that AWS SSO provides by default | Write |  |  |
DeleteMfaDeviceForUser | Deletes a MFA device by device name for a given user | Write |  |  |
DeleteProvisioningTenant | Deletes the provisioning tenant. | Write |  |  |
DeleteUser | Deletes a user from the directory that AWS SSO provides by default | Write |  |  |
DescribeDirectory | Retrieve information about the directory that AWS SSO provides by default | Read |  |  |
DescribeGroups | Retrieves information about group from the directory that AWS SSO provides by default | List |  |  |
DescribeUsers | Retrieves information about user from the directory that AWS SSO provides by default | List |  |  |
DisableExternalIdPConfigurationForDirectory | Disable authentication of end users with an External Identity Provider | Write |  |  |
DisableUser | Deactivates user in the directory that AWS SSO provides by default | Write |  |  |
EnableExternalIdPConfigurationForDirectory | Enable authentication of end users with an External Identity Provider | Write |  |  |
EnableUser | Activates user in the directory that AWS SSO provides by default | Write |  |  |
GetAWSSPConfigurationForDirectory | Retrieve the AWS SSO Service Provider configurations for the directory | Read |  |  |
ListBearerTokens | Lists bearer tokens for a given provisioning tenant. | List |  |  |
ListExternalIdPConfigurationsForDirectory | List all the External Identity Provider configurations created for the directory | List |  |  |
ListGroupsForUser | Lists groups for a user from the directory that AWS SSO provides by default | List |  |  |
ListMembersInGroup | Retrieves all members that are part of the group in the directory that AWS SSO provides by default | List |  |  |
ListMfaDevicesForUser | Lists all active MFA devices and their MFA device metadata for a user | List |  |  |
ListProvisioningTenants | Lists provisioning tenants for a given directory. | List |  |  |
RemoveMemberFromGroup | Removes member that are part of the group in the directory that AWS SSO provides by default | Write |  |  |
SearchGroups | Search for groups within the associated directory | Read |  |  |
SearchUsers | Search for users within the associated directory | Read |  |  |
StartVirtualMfaDeviceRegistration | Begins the creation process of virtual mfa device | Write |  |  |
UpdateExternalIdPConfigurationForDirectory | Update an External Identity Provider configuration associated with the directory | Write |  |  |
UpdateGroup | Updates information about group in the directory that AWS SSO provides by default | Write |  |  |
UpdatePassword | Updates password by sending password reset link via email or generating one time password for a user in the directory that AWS SSO provides by default | Write |  |  |
UpdateUser | Updates user information in the directory that AWS SSO provides by default | Write |  |  |
VerifyEmail | Verify email address of an User | Write |  |  |

## Resource Types Defined by AWS SSO Directory

AWS SSO Directory does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS SSO Directory, specify `“Resource”: “*”` in your policy.

## Condition Keys for AWS SSO Directory

SSO Directory has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference .